/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: KernelVersionSensor.java 410 2009-01-22 12:43:42Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.sensors;

import java.text.MessageFormat;
import java.text.ParseException;
import java.util.HashMap;
import java.util.Map;

/**
 * KernelVersionSensor exposes data sampled from "/proc/version".
 */
public final class KernelVersionSensor extends TextFileSensor implements Sensor {

    /**
     * Id for serializable class.
     */
    private static final long serialVersionUID = -8499111079247453557L;

    /**
     * Default constructor
     */
    public KernelVersionSensor() {
        super("/proc/version");
    }

    /*
     * (non-Javadoc)
     *
     * @see org.ow2.wildcat.sensors.TextFileSensor#getValues(java.lang.String[])
     */
    @Override
    protected Map<String, Object> getValues(final String[] lines) {
        Map<String, Object> samples = new HashMap<String, Object>();
        String version = lines[0];
        samples.put("uname", version);
        try {
            Object[] numbers = (Object[]) VERSION_NUMBER.parseObject(version);
            assert (numbers != null && numbers.length == 3);
            assert (numbers[0] instanceof Integer
                    && numbers[1] instanceof Integer && numbers[2] instanceof Integer);
            samples.put("major-version", numbers[0]);
            samples.put("minor-version", numbers[1]);
            samples.put("patch-level", numbers[2]);
            samples.put("version", numbers[0] + "." + numbers[1] + "."
                    + numbers[2]);
        } catch (ParseException pe) {
            // Do nothing.
        }
        return samples;
    }

    private static final MessageFormat VERSION_NUMBER = new MessageFormat(
    "Linux version {0,number,integer}.{1,number,integer}.{2,number,integer}");
}
