/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * Authors:
 *		- Pierre-Charles David (initial)
 *		- Nicolas Loriant
 * --------------------------------------------------------------------------
 * $Id: Helper.java 399 2009-01-06 14:05:07Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.util;

import org.ow2.wildcat.hierarchy.Path;

/**
 * Helper class, it contains static methods primarily used inside Esper requests.
 */
public final class Helper {

    /**
     * Utility class: private default constructor.
     */
    private Helper() {

    }

    /**
     * Test that path starts with the given prefix.
     *
     * @param path
     *            the Path to test prefix against
     * @param prefix
     *            the prefix to test
     * @return <b>true</b> if both path and prefix are valid finite paths and
     *         path starts with prefix, else <b>false</b>
     */
    public static boolean isPrefix(final String path, final String prefix) {
        try {
            Path pa = new Path(path);
            Path pr = new Path(prefix);

            pa.expectAbsolute();
            pr.expectAbsolute();
            pa.expectCanonical();
            pr.expectCanonical();
            pa.expectFinite();
            pr.expectFinite();

            pr.expectResource();

            return pa.isPrefix(pr);
        } catch (Exception e) {
            return false;
        }
    }
}
