/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2009 Bull S.A.S.
 * Copyright (C) 2009 EMN
 * Copyright (C) 2009 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: QueryTests.java 412 2009-01-23 16:28:47Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.test;

import junit.framework.TestCase;

import com.espertech.esper.client.UpdateListener;
import com.espertech.esper.event.EventBean;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.Query;

/**
 * Unit test for the operations related to queries.
 * @author Mahmoud Ben Hassine
 */
public class QueryTests extends TestCase {

    private int i = 0, j = 0, k = 0;

    public void testRemoveListeners() throws ContextException {

        Context ctx = ContextFactory.getDefaultFactory().createContext();

        Query q1 = ctx.createQuery("select * from WHierarchyEvent");

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                for (EventBean bean : arg0) {
                    i++;
                }
            }

        };

        ctx.registerListeners(q1, ul);

        ctx.createResource("self://r1");
        assertEquals(1, i);

        ctx.removeListeners(q1, ul);

        ctx.createResource("self://r2");

        assertEquals(1, i);

    }

    public void testDestroyQuery() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        Query q1 = ctx.createQuery("select * from WHierarchyEvent");

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                for (EventBean bean : arg0) {
                    j++;
                }
            }

        };

        ctx.registerListeners(q1, ul);

        ctx.createResource("self://r1");
        assertEquals(1, j);

        ctx.destroyQuery(q1);

        ctx.createResource("self://r2");
        assertEquals(1, j);

    }

    public void testPauseResumeQuery() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        Query q1 = ctx.createQuery("select * from WHierarchyEvent");

        UpdateListener ul = new UpdateListener() {

            public void update(final EventBean[] arg0, final EventBean[] arg1) {
                for (EventBean bean : arg0) {
                    System.out
                    .println("WHierarchyEvent : " + bean.getUnderlying().toString());
                    k++;
                }
            }

        };

        ctx.registerListeners(q1, ul);

        ctx.createResource("self://r1");
        assertEquals(1, k);

        ctx.pauseQuery(q1);

        ctx.createResource("self://r2");
        assertEquals(1, k);

        ctx.resumeQuery(q1);

        ctx.createResource("self://r3");
        assertEquals(2, k);

    }

}
