/**
 * WildCAT: A Generic Framework for Context-Aware Applications.
 * Copyright (C) 2008-2009 Bull S.A.S.
 * Copyright (C) 2008 EMN
 * Copyright (C) 2008 IRISA
 * Contact: wildcat@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 *
 * --------------------------------------------------------------------------
 * $Id: TestHierarchyBasicOperations.java 412 2009-01-23 16:28:47Z loris $
 * --------------------------------------------------------------------------
 */
package org.ow2.wildcat.test;

import java.util.concurrent.TimeUnit;

import junit.framework.TestCase;

import org.ow2.wildcat.Context;
import org.ow2.wildcat.ContextException;
import org.ow2.wildcat.ContextFactory;
import org.ow2.wildcat.hierarchy.Path;
import org.ow2.wildcat.hierarchy.resource.Resource;
import org.ow2.wildcat.sensors.SensorLibrary;

public class TestHierarchyBasicOperations extends TestCase {

    public void testdetachResource() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        ctx.createResource("self://resource1/resource3");
        ctx.createResource("self://resource2");

        ctx.detachResource("self://resource1");

        assertEquals("[resource2]", ctx.list("self://").toString());

    }

    public void testdetachLinkedResource() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        ctx.createResource("self://resource1");
        ctx.createResource("self://resource2");

        ctx.createAttribute("self://resource1#att", "a1");

        ctx.createSymlink("self://link", "self://resource1");

        ctx.detachResource("self://resource1");
        assertEquals(null, ctx.list("self://link"));

    }

    public void testdestroyContext() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        ctx.createAttribute("self://start#a1", "start");
        ctx.createAttribute("self://start#a2", "end");
        ctx.createResource("self://resource");
        ctx.destroy();
        assertEquals("[]", ctx.list("self://").toString());

    }

    public void testGetResource() throws ContextException {

        Context ctx = ContextFactory.getDefaultFactory().createContext();
        ctx.createResource("self://r1/r3");
        ctx.createResource("self://r2");

        Resource r = ctx.getResource("self://r1/r3");

        assertNotNull(r);

    }

    public void testPath() throws Exception {
        Path path1 = new Path("self://foo/bar");
        Path path2 = new Path("self://foo/bar#att");
        assertEquals(path1.getParentPath().appendResource("bar"), path2.getParentPath());
    }

//	public void testGetAttribute() {
//
//		AccountSensor cpt1 = new AccountSensor(0, "mahmoud", ClientType.Bronze);
//		Context ctx = ContextFactory.getDefaultFactory().createContext();
//		try {
//			ctx.attachAttribute("self://bank/accounts#mahmoud", cpt1);
//
//			Attribute cpt = ctx.getAttribute("self://bank/accounts#mahmoud");
//
//			assertNotNull(cpt);
//
//		} catch (ContextException e) {
//			e.printStackTrace();
//		}
//
//	}

    public void testdetachAttribute() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        ctx.attachAttribute("self://start#time", SensorLibrary.DEFAULT
                .instanciate("DateTime"));

        ctx.detachAttribute("self://start#time");
        assertNull(ctx.getValue("self://start#time"));
    }

    public void testremovePAP() throws ContextException {
        Context ctx = ContextFactory.getDefaultFactory().createContext();

        ctx.createAttribute("self://start#a1", "mbh");

        ctx.createPeriodicAttributePoller("self://start#a1", 1,
                TimeUnit.SECONDS);

        ctx.removePeriodicAttributePoller("self://start#a1");

    }

}
